var indexSectionsWithContent =
{
  0: "012345678abcdefghilmnopqrstvx",
  1: "afimsx",
  2: "q",
  3: "abcdefghilmnoprstvx",
  4: "ehmnx",
  5: "cefgmnoprtx",
  6: "dglmoqx"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "namespaces",
  3: "functions",
  4: "variables",
  5: "groups",
  6: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Namespaces",
  3: "Functions",
  4: "Variables",
  5: "Modules",
  6: "Pages"
};

